@@ -12,7 +12,7 @@
 #'
 download_metadata <- function(){
 
-  # Get metadata with data addresses
+  # create tempfile to save metadata
   tempf <- file.path(tempdir(), "metadata.csv")
 
   # check if metadata has already been downloaded
@@ -20,8 +20,16 @@ download_metadata <- function(){
     metadata <- utils::read.csv(tempf, stringsAsFactors=F)
 
   } else {
+
+    # test server connection
+    metadata_link <- 'http://www.ipea.gov.br/geobr/metadata/metadata_gpkg.csv'
+    t <- try( open.connection(con = url(metadata_link), open="rt", timeout=2),silent=T)
+    if("try-error" %in% class(t)){stop('Internet connection problem. If this is not a connection problem in your network, please try geobr again in a few minutes.')}
+
+    suppressWarnings(try(close.connection(con),silent=T))
+
     # download it and save to metadata
-    httr::GET(url="http://www.ipea.gov.br/geobr/metadata/metadata_gpkg.csv", httr::write_disk(tempf, overwrite = T))
+    httr::GET(url= metadata_link, httr::write_disk(tempf, overwrite = T))
     metadata <- utils::read.csv(tempf, stringsAsFactors=F)
   }
 
