@@ -4,9 +4,11 @@
 #'
 #' @param year Year of the data (defaults to 2010)
 #' @param code_state The two-digit code of a state or a two-letter uppercase abbreviation (e.g. 33 or "RJ"). If code_state="all", all states will be loaded.
-#' @param simplified Logic TRUE or FALSE, indicating whether the function returns the 'original' dataset with high resolution or a dataset with 'simplified' borders (Defaults to TRUE)
+#' @param simplified Logic FALSE or TRUE, indicating whether the function returns the
+#'  data set with 'original' resolution or a data set with 'simplified' borders (Defaults to TRUE).
+#'  For spatial analysis and statistics users should set simplified = FALSE. Borders have been
+#'  simplified by removing vertices of borders using st_simplify{sf} preserving topology with a dTolerance of 100.
 #' @param showProgress Logical. Defaults to (TRUE) display progress bar
-#' @param tp Argument deprecated. Please use argument 'simplified'
 #'
 #' @export
 #' @family general area functions
@@ -25,10 +27,7 @@
 #'
 #'}
 
-read_state <- function(code_state="all", year=2010, simplified=TRUE, showProgress=TRUE, tp){
-
-  # deprecated 'tp' argument
-  if (!missing("tp")){stop(" 'tp' argument deprecated. Please use argument 'simplified' TRUE or FALSE")}
+read_state <- function(code_state="all", year=2010, simplified=TRUE, showProgress=TRUE){
 
   # Get metadata with data url addresses
   temp_meta <- select_metadata(geography="state", year=year, simplified=simplified)
@@ -45,18 +44,30 @@ if( x < 1992){
 #       stop("Error: Invalid Value to argument code_state.")
 #       }
 
-  if(is.null(code_state)){ stop("Value to argument 'code_state' cannot be NULL") }
+  if(is.null(code_state)){ stop("Value to argument 'code_state' cannot be NULL")}
 
-  message("Loading data for the whole country\n")
+  if(code_state=="all"){ message("Loading data for the whole country\n")
 
-  # list paths of files to download
-  file_url <- as.character(temp_meta$download_path)
+    # list paths of files to download
+    file_url <- as.character(temp_meta$download_path)
 
-  # download files
-  temp_sf <- download_gpkg(file_url, progress_bar = showProgress)
-  return(temp_sf)
+    # download gpkg
+    temp_sf <- download_gpkg(file_url, progress_bar = showProgress)
+    return(temp_sf)
 
-} else {
+  } else if(nchar(code_state)==2){
+
+    # list paths of files to download
+    file_url <- as.character(temp_meta$download_path)
+
+    # download gpkg
+    temp_sf <- download_gpkg(file_url, progress_bar = showProgress)
+
+    temp_sf <- subset(temp_sf,code_state==substr(code_state, 1, 2))
+    return(temp_sf)
+  }
+
+}  else {
 
 
 # BLOCK 2.2 From 2000 onwards  ----------------------------
