@@ -14,9 +14,6 @@ test_that("read_metro_area", {
   test_sf <- read_metro_area(year=2001)
   expect_true(is(test_sf, "sf"))
 
-  # check projection
-    expect_equal(sf::st_crs(test_sf)[[2]], "+proj=longlat +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +no_defs")
-
 })
 
 
